/*
 * jDocBook, processing of DocBook sources as a Maven plugin
 *
 * Copyright (c) 2008, Red Hat Middleware LLC or third-party contributors as
 * indicated by the @author tags or express copyright attribution
 * statements applied by the authors.  All third-party contributions are
 * distributed under license by Red Hat Middleware LLC.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 *
 */
package org.jboss.jdocbook.i18n;

import org.jboss.jdocbook.i18n.gettext.PoSynchronizerImpl;
import org.jboss.jdocbook.i18n.gettext.PotSynchronizerImpl;
import org.jboss.jdocbook.i18n.gettext.TranslationBuilderImpl;

/**
 * Factory for various i18n components.  Statically bound to "gettext" versions.
 *
 * @author Steve Ebersole
 */
public class Factory {
	private static final PotSynchronizer potSynchronizer = new PotSynchronizerImpl();
	private static final PoSynchronizer poSynchronizer = new PoSynchronizerImpl();
	private static final TranslationBuilder translationBuilder = new TranslationBuilderImpl();

	/**
	 * Disallow instantiation
	 */
	private Factory() {
	}

	public static PotSynchronizer getPotSynchronizer() {
		return potSynchronizer;
	}

	public static PoSynchronizer getPoSynchronizer() {
		return poSynchronizer;
	}

	public static TranslationBuilder getTranslationBuilder() {
		return translationBuilder;
	}
}
